@@ -5,11 +5,11 @@ use strict;
 use Apache::Session;
 use Apache::Session::Lock::Null;
 use Apache::Session::Browseable::Store::Oracle;
-use Apache::Session::Generate::MD5;
-use Apache::Session::Serialize::Base64;
+use Apache::Session::Generate::SHA256;
+use Apache::Session::Serialize::JSON
 use Apache::Session::Browseable::DBI;
 
-our $VERSION = '0.2';
+our $VERSION = '1.2.2';
 our @ISA     = qw(Apache::Session::Browseable::DBI Apache::Session);
 
 sub populate {
@@ -18,10 +18,10 @@ sub populate {
     $self->{object_store} =
       new Apache::Session::Browseable::Store::Oracle $self;
     $self->{lock_manager} = new Apache::Session::Lock::Null $self;
-    $self->{generate}     = \&Apache::Session::Generate::MD5::generate;
-    $self->{validate}     = \&Apache::Session::Generate::MD5::validate;
-    $self->{serialize}    = \&Apache::Session::Serialize::Base64::serialize;
-    $self->{unserialize}  = \&Apache::Session::Serialize::Base64::unserialize;
+    $self->{generate}     = \&Apache::Session::Generate::SHA256::generate;
+    $self->{validate}     = \&Apache::Session::Generate::SHA256::validate;
+    $self->{serialize}    = \&Apache::Session::Serialize::JSONserialize;
+    $self->{unserialize}  = \&Apache::Session::Serialize::JSONunserialize;
 
     return $self;
 }
